import path from 'path';
import isBuiltinModule from 'is-builtin-module';
import { getOptionsObject } from '@rollup-extras/utils/options';
import logger from '@rollup-extras/utils/logger';
import packageDirectory from 'pkg-dir';

const factories = { logger };
function index (options = {}) {
    const { pluginName, external, logger, verbose } = getOptionsObject(options, {
        pluginName: '@rollup-extras/plugin-externals',
        verbose: false
    }, factories);
    const logLevel = verbose ? 1 /* info */ : 0 /* verbose */;
    let pkgDir = false;
    return {
        name: pluginName,
        async resolveId(id, importer) {
            var _a;
            if (pkgDir === false) {
                pkgDir = (_a = (await packageDirectory())) !== null && _a !== void 0 ? _a : '.';
            }
            const importingFileName = path.resolve(path.dirname(importer || ''), id);
            let isExternal = id.includes('node_modules') || isBuiltinModule(id) || path.relative(pkgDir, importingFileName).startsWith('..');
            if (external) {
                isExternal = external(id, isExternal, importer);
            }
            logger(`'${id}' is ${isExternal ? '' : 'not '}external`, logLevel);
            return isExternal ? false : null;
        }
    };
}

export { index as default };
